==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiPage/GetSubjectVisitor.pm <==
#
# WiKicker
#
#  GetSubjectVisitor.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: GetSubjectVisitor.pm,v 1.6 2003/11/08 06:44:07 naney Exp $
#
#

package WiKicker::WikiPage::GetSubjectVisitor;

use strict;
use Carp;
use WiKicker::UTF8;
use WiKicker::PageName;
use WiKicker::WikiPage::TraverseVisitor;
use WiKicker::WRI::Resolver;
use WiKicker::WikiPage::Env;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiPage::TraverseVisitor);

sub new {
  my ($class, %param) = @_;

  croak "no wri_factory" unless defined $param{wri_factory};
  
  my $self = bless { subject => "" }, $class;

  $self->{resolver} = WiKicker::WRI::Resolver->new;
  $self->{env}
    = WiKicker::WikiPage::Env->new(resolver => $self->{resolver},
                                   wri_factory => $param{wri_factory},
                                  );

  return $self;
}

sub subject {
  my ($self, $length) = @_;

  my $subject = $self->{subject};
  $subject =~ s/\n//g;
  $subject =~ s/\s+/ /g;
  $subject =~ s/^\s+//;
  $subject =~ s/\s+$//;

  if (WiKicker::UTF8::length_utf8($subject) <= $length) {
    return $subject;
  }

  if ($length > 3) {
    my $result = WiKicker::UTF8::substr_utf8($subject, 0, $length - 3);
    return $result .= '...';
  }
  return WiKicker::UTF8::substr_utf8($subject, 0, $length);
}

my %accept_node_class =
  (
   'WiKicker::WikiPage::ParagraphNode' => 1,
   'WiKicker::WikiPage::PreNode' => 1,
   'WiKicker::WikiPage::ListNode' => 1,
   'WiKicker::WikiPage::QuoteNode' => 1);

sub visit_DocumentNode {
  my ($self, $document_node) = @_;

  for my $node ($document_node->nodes) {
    $node->accept($self) if exists $accept_node_class{ref $node};
  }
}

sub visit_ParagraphNode {
  my ($self, $paragraph_node) = @_;
  for my $node ($paragraph_node->nodes) {
    $node->accept($self);
  }
  $self->{subject} .= ' ';
}

sub visit_TextNode {
  my ($self, $text_node) = @_;

  $self->{subject} .= $text_node->to_string;
}

sub visit_VerbatimNode {
  my ($self, $node) = @_;

  $self->{subject} .= $node->text;
}

sub visit_WriNode {
  my ($self, $wri_node) = @_;

  $self->{subject}
    .= $wri_node->wri->to_subject_string($self->{env});
}

sub visit_BracketNameNode {
  my ($self, $bracket_name_node) = @_;

  if ($bracket_name_node->content) {
    $self->{subject} .= $bracket_name_node->content;
  }
  else {
    $self->{subject}
      .= $bracket_name_node->wri->to_subject_string($self->{env});
  }
}

sub visit_ListNode {
  my ($self, $list_node) = @_;

  my $first = 1;
  for my $node ($list_node->nodes) {
    unless ($first) {
      $self->{subject} .= ' / ';
    }
    $node->accept($self);
    $first = 0;
  }
}

sub visit_PreNode {
  my ($self, $pre_node) = @_;
  $self->{subject} .= $pre_node->to_string;
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiPage/GetSubjectVisitor.pm <==
#
# WiKicker
#
#  GetSubjectVisitor.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: GetSubjectVisitor.pm,v 1.8 2005/02/04 13:30:10 naney Exp $
#
#

package WiKicker::WikiPage::GetSubjectVisitor;

use strict;
use Carp;
use WiKicker::UTF8;
use WiKicker::PageName;
use WiKicker::WikiPage::TraverseVisitor;
use WiKicker::WRI::Resolver;
use WiKicker::WikiPage::Env;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiPage::TraverseVisitor);

sub new {
  my ($class, %param) = @_;

  croak 'no wri_factory' unless defined $param{wri_factory};

  my $self = bless { subject => '' }, $class;

  $self->{resolver} = WiKicker::WRI::Resolver->new;
  $self->{env}
    = WiKicker::WikiPage::Env->new(resolver => $self->{resolver},
                                   wri_factory => $param{wri_factory},
                                  );

  return $self;
}

sub subject {
  my ($self, $length) = @_;

  my $subject = $self->{subject};
  $subject =~ s/\n//g;
  $subject =~ s/\s+/ /g;
  $subject =~ s/^\s+//;
  $subject =~ s/\s+$//;

  return WiKicker::UTF8::shorten($subject, $length);
}

my %accept_node_class =
  (
   'WiKicker::WikiPage::ParagraphNode' => 1,
   'WiKicker::WikiPage::PreNode' => 1,
   'WiKicker::WikiPage::ListNode' => 1,
   'WiKicker::WikiPage::QuoteNode' => 1);

sub visit_DocumentNode {
  my ($self, $document_node) = @_;

  for my $node ($document_node->nodes) {
    $node->accept($self) if exists $accept_node_class{ref $node};
  }
}

sub visit_ParagraphNode {
  my ($self, $paragraph_node) = @_;
  for my $node ($paragraph_node->nodes) {
    $node->accept($self);
  }
  $self->{subject} .= ' ';
}

sub visit_TextNode {
  my ($self, $text_node) = @_;

  $self->{subject} .= $text_node->to_string;
}

sub visit_VerbatimNode {
  my ($self, $node) = @_;

  $self->{subject} .= $node->text;
}

sub visit_WriNode {
  my ($self, $wri_node) = @_;

  $self->{subject}
    .= $wri_node->wri->to_subject_string($self->{env});
}

sub visit_BracketNameNode {
  my ($self, $bracket_name_node) = @_;

  if ($bracket_name_node->content) {
    $self->{subject} .= $bracket_name_node->content;
  }
  else {
    $self->{subject}
      .= $bracket_name_node->wri->to_subject_string($self->{env});
  }
}

sub visit_ListNode {
  my ($self, $list_node) = @_;

  my $first = 1;
  for my $node ($list_node->nodes) {
    unless ($first) {
      $self->{subject} .= ' / ';
    }
    $node->accept($self);
    $first = 0;
  }
}

sub visit_PreNode {
  my ($self, $pre_node) = @_;
  $self->{subject} .= $pre_node->to_string;
}

1;
